%define	major		12
%define libname		%mklibname idn %{major}
%define develname	%mklibname idn -d

# this is needed to avoid make check failures
%define _disable_ld_as_needed 1

Summary:	Internationalized string processing library
Name:		libidn
Version:	1.42
Release:	%mkrel 1
License:	LGPLv2+
Group:		System/Libraries
URL:		https://www.gnu.org/software/libidn/
Source0:	https://ftp.gnu.org/gnu/libidn/%{name}-%{version}.tar.gz
Source1:	https://ftp.gnu.org/gnu/libidn/%{name}-%{version}.tar.gz.sig
BuildRequires:	texinfo
BuildRequires:	autoconf
BuildRequires:	automake
BuildRequires:	gettext-devel
BuildRequires:	help2man
BuildRequires:	autoconf-archive
BuildRequires:	valgrind
BuildRequires:	javapackages-tools
BuildRequires:	java-devel
BuildRequires:	antlr
BuildRequires:	javapackages-local
BuildRequires:	mvn(com.google.guava:guava)
BuildRequires:	mvn(junit:junit)
# disable on arm for now. test it again on real hardware. qemu doesn't like it
%ifnarch %arm aarch64
BuildRequires:	mono-core
%endif

%description
GNU Libidn is an implementation of the Stringprep, Punycode and
IDNA specifications defined by the IETF Internationalized Domain
Names (IDN) working group, used for internationalized domain
names.

%package -n %{libname}
Summary:	Internationalized string processing library
Group:		System/Libraries

%description -n	%{libname}
GNU Libidn is an implementation of the Stringprep, Punycode and
IDNA specifications defined by the IETF Internationalized Domain
Names (IDN) working group, used for internationalized domain
names.

%package -n %{develname}
Summary:	Development files for the %{libname} library
Group:		Development/C
Provides:	%{name}-devel = %{version}-%{release}
Provides:	idn-devel = %{version}-%{release}
Requires:	%{libname} = %{version}-%{release}
Requires:	pkgconfig

%description -n	%{develname}
Development files for the %{libname} library.

%package -n idn
Summary:	Commandline interface to the %{libname} library
Group:		System/Servers

%description -n idn
This package provides the commandline interface to the
%{libname} library.

%package -n %{libname}-java
Summary:	Java support for the %{name}
Group:		Development/Java
Provides:	%{name}-java = %{version}-%{release}
Requires:	%{libname} = %{version}-%{release}

%description -n %{libname}-java
Java support for the %{name}.


%package javadoc
Summary:       Javadoc for %{name}-java
BuildArch:     noarch

%description javadoc
This package contains javadoc for %{name}-java.


%ifnarch %arm aarch64
%package -n %{libname}-mono
Summary:	Mono support for the %{name}
Group:		Development/Other
Provides:	%{name}-mono = %{version}-%{release}
Requires:	%{libname} = %{version}-%{release}

%description -n %{libname}-mono
Mono support for the %{name}.
%endif

%prep
%setup -q
%autopatch -p1

# Cleanup
find . -name '*.jar' -print -delete
find . -name '*.class' -print -delete

# Not available test dep
%pom_remove_dep com.google.caliper:caliper java/pom.xml.in
# Unused dependency
%pom_remove_dep com.google.code.findbugs:annotations java/pom.xml.in

%build
autoreconf -vfi
%configure --disable-static \
	--enable-java \
	--disable-valgrind-tests \
%ifnarch %arm aarch64
	--enable-csharp=mono \
%endif
	--disable-rpath

%make_build

%check
# without RPATH this needs to be set to test the compiled library
export LD_LIBRARY_PATH=$(pwd)/lib/.libs
%make_build -C tests check VALGRIND=env

%install
%make_install

# fix "invalid-lc-messages-dir":
rm -rf %{buildroot}%{_datadir}/locale/en@*quot

%find_lang %{name}

#(tpg) really not needed... also got lzma'd :)

rm -rf %{buildroot}%{_infodir}/*.png*
find %{buildroot} -name '*.la' -delete

# this fixes a file clash in a mixed arch env
mv %{buildroot}%{_infodir}/%{name}.info %{buildroot}%{_infodir}/%{libname}.info


# regenerate java documentation
rm -rf doc/java/*
%javadoc -source 1.7 -d doc/java $(find java/src/main/java -name "*.java")
# generate maven depmap
rm -rf %{buildroot}%{_javadir}/libidn*.jar
%mvn_artifact java/pom.xml java/libidn-%{version}.jar
%mvn_file org.gnu.inet:libidn libidn
%mvn_install -J doc/java

%files -n idn -f %{name}.lang
%doc ChangeLog FAQ README THANKS
%{_bindir}/idn
%{_mandir}/man1/idn.1*
%{_datadir}/emacs/site-lisp/*.el

%files -n %{libname}
%{_libdir}/libidn.so.%{major}{,.*}
%{_infodir}/%{libname}.info*

%files -n %{develname}
%doc libc/example.c examples/README examples/Makefile.*
%{_libdir}/libidn.so
%{_includedir}/*.h
%{_libdir}/pkgconfig/*.pc
%{_mandir}/man3/*

%files -n %{libname}-java -f .mfiles

%files javadoc -f .mfiles-javadoc
%license COPYING* java/LICENSE-2.0.txt

%ifnarch %arm aarch64
%files -n %{libname}-mono
%{_libdir}/*.dll
%endif


%changelog
* Wed Feb 07 2024 daviddavid <daviddavid> 1.42-1.mga10
+ Revision: 2038411
- new version: 1.42

* Wed Sep 21 2022 pterjan <pterjan> 1.41-2.mga9
+ Revision: 1891309
- Fix file list
- Fix javadoc command and enable java stuff on aarch64 too
- Better remove findbugs:annotations dependency
+ luigiwalser <luigiwalser>
- 1.41
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild

* Thu Aug 05 2021 luigiwalser <luigiwalser> 1.38-1.mga9
+ Revision: 1739627
- 1.38

* Mon May 17 2021 daviddavid <daviddavid> 1.37-1.mga9
+ Revision: 1725278
- new version: 1.37
- remove merged upstream patch

* Fri Dec 11 2020 wally <wally> 1.36-2.mga8
+ Revision: 1655462
- fix build with autoconf 2.70
- drop mips support

* Sun Jul 26 2020 daviddavid <daviddavid> 1.36-1.mga8
+ Revision: 1609179
- new version: 1.36

* Wed Feb 26 2020 umeabot <umeabot> 1.35-3.mga8
+ Revision: 1550749
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Mon Sep 03 2018 tv <tv> 1.35-2.mga7
+ Revision: 1256623
- rely on filetriggers for info system (mga#23482)

* Fri May 11 2018 kekepower <kekepower> 1.35-1.mga7
+ Revision: 1228356
- BR autoconf-archive
- Update make macros
- Update to version 1.35

* Sat Mar 31 2018 kekepower <kekepower> 1.34-1.mga7
+ Revision: 1213963
- Update to version 1.34
+ wally <wally>
- add minimal build support for aarch64

* Wed Oct 04 2017 ns80 <ns80> 1.33-3.mga7
+ Revision: 1168429
- add patch for CVE-2017-14062 (mga#21800)

* Mon Sep 11 2017 tv <tv> 1.33-2.mga7
+ Revision: 1152928
- drop BR on gcj-tools

* Thu Jul 21 2016 luigiwalser <luigiwalser> 1.33-1.mga6
+ Revision: 1043006
- 1.33 (fixes CVE-2015-8948 and CVE-2016-626[1-3])

* Sun Mar 13 2016 neoclust <neoclust> 1.32-4.mga6
+ Revision: 990067
- Fix java part

* Mon Feb 15 2016 umeabot <umeabot> 1.32-3.mga6
+ Revision: 961036
- Mageia 6 Mass Rebuild

* Fri Oct 30 2015 tv <tv> 1.32-2.mga6
+ Revision: 896665
- fix build by killing empty file list

* Wed Sep 02 2015 luigiwalser <luigiwalser> 1.32-1.mga6
+ Revision: 872228
- 1.32 (fixes CVE-2015-2059)

* Fri Aug 21 2015 tmb <tmb> 1.29-4.mga6
+ Revision: 867610
- rebuild for new gcc

* Wed Oct 15 2014 umeabot <umeabot> 1.29-3.mga5
+ Revision: 744626
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.29-2.mga5
+ Revision: 681529
- Mageia 5 Mass Rebuild

* Fri Aug 15 2014 luigiwalser <luigiwalser> 1.29-1.mga5
+ Revision: 662889
- 1.29

* Fri Jan 03 2014 luigiwalser <luigiwalser> 1.28-4.mga4
+ Revision: 564229
- submit to core/release

* Thu Jan 02 2014 danf <danf> 1.28-3.mga4
+ Revision: 563926
- Fixed test failures due to improper linking
+ umeabot <umeabot>
- Mageia 4 Mass Rebuild

* Thu Oct 10 2013 luigiwalser <luigiwalser> 1.28-2.mga4
+ Revision: 494374
- update java BRs

* Tue Jul 16 2013 luigiwalser <luigiwalser> 1.28-1.mga4
+ Revision: 455112
- 1.28
- remove upstreamed fixes

* Mon Jun 24 2013 luigiwalser <luigiwalser> 1.27-1.mga4
+ Revision: 446091
- run autoreconf since it tries to run automake-1.11
- BR gcj-tools for gjdoc needed to build javadoc
- add RangeSet.java missing from upstream tarball
- add upstream patches to fix crash and compilation problem
- 1.27

* Sat Jan 12 2013 umeabot <umeabot> 1.26-2.mga3
+ Revision: 357512
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Tue Dec 25 2012 luigiwalser <luigiwalser> 1.26-1.mga3
+ Revision: 334826
- 1.26

* Thu May 31 2012 fwang <fwang> 1.25-1.mga3
+ Revision: 252030
- new version 1.25

* Thu Jan 12 2012 fwang <fwang> 1.24-1.mga2
+ Revision: 195332
- disable valgrind test as suggested by upstream
- new version 1.24
- new version 1.23

* Tue Jun 28 2011 fwang <fwang> 1.22-1.mga2
+ Revision: 115103
- sync sig
- new verison 1.22

* Fri Jan 14 2011 blino <blino> 1.19-2.mga1
+ Revision: 17383
- remove old ldconfig scriptlets
+ ahmad <ahmad>
- imported package libidn


* Mon Jul 12 2010 Oden Eriksson <oeriksson@mandriva.com> 1.19-1mdv2011.0
+ Revision: 551247
- 1.19

* Mon Feb 15 2010 Frederik Himpe <fhimpe@mandriva.org> 1.18-1mdv2010.1
+ Revision: 506370
- Update to new version 1.18

* Fri Jan 15 2010 Emmanuel Andry <eandry@mandriva.org> 1.16-1mdv2010.1
+ Revision: 491778
- New version 1.16

* Sun Sep 27 2009 Olivier Blin <oblin@mandriva.com> 1.15-2mdv2010.0
+ Revision: 449884
- disable mono/java/valgrind on mips & arm (from Arnaud Patard)

* Mon Jun 08 2009 Frederik Himpe <fhimpe@mandriva.org> 1.15-1mdv2010.0
+ Revision: 384104
- Update to new version 1.15

* Sat May 02 2009 Tomasz Pawel Gajc <tpg@mandriva.org> 1.14-1mdv2010.0
+ Revision: 370768
- update to new version 1.14

* Sat Mar 07 2009 Tomasz Pawel Gajc <tpg@mandriva.org> 1.13-2mdv2009.1
+ Revision: 350829
- update to new version 1.13

* Tue Dec 16 2008 Oden Eriksson <oeriksson@mandriva.com> 1.11-2mdv2009.1
+ Revision: 314889
- rebuild

* Sun Nov 16 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 1.11-1mdv2009.1
+ Revision: 303615
- update to new version 1.11

  + Oden Eriksson <oeriksson@mandriva.com>
    - fix url

* Mon Sep 01 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 1.10-1mdv2009.0
+ Revision: 278163
- update to new version 1.10

* Fri Jul 11 2008 Oden Eriksson <oeriksson@mandriva.com> 1.9-1mdv2009.0
+ Revision: 233845
- 1.9

  + Pixel <pixel@mandriva.com>
    - do not call ldconfig in %%post/%%postun, it is now handled by filetriggers

* Sun May 11 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 1.8-1mdv2009.0
+ Revision: 205890
- new version
- enable valgrind tests
- add java and mono subpackages
- fix file list

* Sun Apr 13 2008 Oden Eriksson <oeriksson@mandriva.com> 1.7-1mdv2009.0
+ Revision: 192656
- 1.7

* Thu Feb 21 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 1.5-1mdv2008.1
+ Revision: 173451
- new version

* Wed Jan 23 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 1.4-1mdv2008.1
+ Revision: 157102
- new version
- remove buildrequires on libtool and autoconf
- add *.sig file
- mode docs to the binary package
- spec file clean

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Wed Dec 12 2007 Tomasz Pawel Gajc <tpg@mandriva.org> 1.3-1mdv2008.1
+ Revision: 117624
- new version

* Tue Oct 16 2007 Tomasz Pawel Gajc <tpg@mandriva.org> 1.2-1mdv2008.1
+ Revision: 98832
- new version
- new license policy

* Tue Sep 18 2007 Thierry Vignaud <tv@mandriva.org> 1.0-2mdv2008.0
+ Revision: 89677
- rebuild

* Tue Jul 31 2007 Oden Eriksson <oeriksson@mandriva.com> 1.0-1mdv2008.0
+ Revision: 57251
- 1.0

* Thu Jul 19 2007 Tomasz Pawel Gajc <tpg@mandriva.org> 0.6.14-1mdv2008.0
+ Revision: 53647
- new devel library policy
- remove not needed files
- disable rpath
- spec file clean
- new version


* Mon Mar 19 2007 Thierry Vignaud <tvignaud@mandriva.com> 0.6.9-3mdv2007.1
+ Revision: 146601
- move devel doc in -devel

* Mon Mar 05 2007 Oden Eriksson <oeriksson@mandriva.com> 0.6.9-2mdv2007.1
+ Revision: 133202
- fix a libname dependant file clash

* Sun Mar 04 2007 Oden Eriksson <oeriksson@mandriva.com> 0.6.9-1mdv2007.1
+ Revision: 132136
- second try...
- 0.6.9
- prevent future mess with major

* Tue Oct 31 2006 Oden Eriksson <oeriksson@mandriva.com> 0.6.8-1mdv2007.1
+ Revision: 74284
- 0.6.8
- misc spec file fixes
- Import libidn

* Sat Jul 08 2006 Oden Eriksson <oeriksson@mandriva.com> 0.6.5-1mdk
- 0.6.5

* Tue Feb 07 2006 Oden Eriksson <oeriksson@mandriva.com> 0.6.2-1mdk
- 0.6.2 (Minor feature enhancements)

* Fri Jan 20 2006 Oden Eriksson <oeriksson@mandriva.com> 0.6.1-1mdk
- 0.6.1

* Thu Dec 22 2005 Oden Eriksson <oeriksson@mandriva.com> 0.6.0-2mdk
- install-info/info-install (duh!)

* Thu Dec 22 2005 Oden Eriksson <oeriksson@mandriva.com> 0.6.0-1mdk
- 0.6.0

* Tue Oct 25 2005 Oden Eriksson <oeriksson@mandriva.com> 0.5.20-1mdk
- 0.5.20 (Minor bugfixes)

* Sat Oct 08 2005 Oden Eriksson <oeriksson@mandriva.com> 0.5.19-1mdk
- 0.5.19

* Thu Aug 11 2005 Oden Eriksson <oeriksson@mandriva.com> 0.5.18-2mdk
- fix #77181

* Tue Jul 19 2005 Oden Eriksson <oeriksson@mandriva.com> 0.5.18-1mdk
- 0.5.18 (Minor bugfixes)

* Fri May 27 2005 Oden Eriksson <oeriksson@mandriva.com> 0.5.17-1mdk
- 0.5.17

* Tue May 10 2005 Oden Eriksson <oeriksson@mandriva.com> 0.5.16-1mdk
- 0.5.16

* Sun Apr 17 2005 Oden Eriksson <oeriksson@mandriva.com> 0.5.15-1mdk
- 0.5.15
- use the %%mkrel macro
- fix requires-on-release

* Sun Jan 30 2005 Oden Eriksson <oeriksson@mandrakesoft.com> 0.5.13-1mdk
- 0.5.13

* Sun Dec 05 2004 Oden Eriksson <oeriksson@mandrakesoft.com> 0.5.12-1mdk
- 0.5.12

* Tue Nov 09 2004 Oden Eriksson <oeriksson@mandrakesoft.com> 0.5.10-1mdk
- 0.5.10

* Mon Nov 08 2004 Oden Eriksson <oeriksson@mandrakesoft.com> 0.5.9-1mdk
- 0.5.9

* Mon Oct 11 2004 Oden Eriksson <oeriksson@mandrakesoft.com> 0.5.6-1mdk
- 0.5.6

* Mon Aug 09 2004 Oden Eriksson <oeriksson@mandrakesoft.com> 0.5.4-1mdk
- 0.5.4

* Thu Jul 15 2004 Oden Eriksson <oeriksson@mandrakesoft.com> 0.5.2-1mdk
- 0.5.2

* Tue Jul 13 2004 Oden Eriksson <oeriksson@mandrakesoft.com> 0.5.1-1mdk
- 0.5.1

* Mon Jun 28 2004 Oden Eriksson <oeriksson@mandrakesoft.com> 0.5.0-1mdk
- 0.5.0

* Mon Jun 14 2004 Oden Eriksson <oeriksson@mandrakesoft.com> 0.4.9-1mdk
- 0.4.9

* Sun Jun 06 2004 Oden Eriksson <oeriksson@mandrakesoft.com> 0.4.8-1mdk
- 0.4.8

* Wed Jun 02 2004 Lenny Cartier <lenny@mandrakesoft.com> 0.4.7-1mdk
- 0.4.7

* Wed May 26 2004 Oden Eriksson <oeriksson@mandrakesoft.com> 0.4.6-1mdk
- 0.4.6

* Tue May 25 2004 Lenny Cartier <lenny@mandrakesoft.com> 0.4.5-1mdk
- 0.4.5

* Thu May 06 2004 Oden Eriksson <oeriksson@mandrakesoft.com> 0.4.4-1mdk
- 0.4.4, thanks to Michael Scherer for helping with the locale stuff

